---
title: "More Exploration of Social Objects"
date: 2022-09-04T01:03:22+01:00
tags: ["relativism","subjectivism","realism"]
topics: ["ontology", "metaphysics"]
image: img/chess-board-resized.jpg
description: Once more, with less feeling...
draft: false
---

### Are Social Objects "*Really* Real"?

There is an intuitive suspicion expressed in common sense, that certain kinds of objects -- namely, objects that seem to be dependent upon social factors -- aren't "*really*, real". The intuition is a skeptical one arising out of a default common sense empiricism. While there may be some nominal understanding or some social agreement about the reality of things like national borders or governments, they're not "*really*, real" in the sense that, say, an airplane, or a boulder, or a dog, are "*really*, real". In contemporary philosophical literature, this distinction is typically understood as an  opposition between the realist and antirealist understanding of objects, and is sometimes justified by adding the qualification "social" to the term object. The qualification is correct, but incomplete. This paper will attempt flesh out the notion of a social object, in order to provide a clearer understanding of what is meant by it, and to provide a means by which we might answer the question of whether so-called social objects are in fact, "*really*, real".

### Social Objects

To begin the analysis of social objects, we need to clarify our understanding of the component terms in the question. What are "objects", what does it mean for them to be "real" or "social", and what is it about the social qualification that seems to suggest an ontological demotion?

We have many not-quite substitute terms for 'object'. For example, being, entity, instance, and thing. These are not definitions, but varying attempts to express an idea about the way in which human beings experience the constituents of existence. There are two common sense understandings of this term: (a) that which is *tangible*. Which is to say, that which is numerically distinct, a unity, and perceptible by the senses, and (b) that which is the focus of one's cognition, attention, or emotion. Neither of these definitions accounts for the qualified idea of a 'social' object. While social objects may indeed be at times the focus of attention or emotion, definition (b) seems to not pick out anything in particular. We can focus our attention on a flower, or on a baseball team, or on a project. So, all of these things can be an object in the sense of definition (b). The qualification of social, therefore, appears irrelevent to definition (b), and thus must be an attempt to isolate certain objects from the objects captured by definition (a). In short, a social object is a different kind of object from a tangible object. But what kind of object is that?

Having an outline or rough idea of what social objects are *not* is necessary for a full definition, it is not sufficient. This gray area may be one source for the intuition that social objects are not "*really* real". If they fail to conform to the first definition, and we cannot provide a definition for the other category, then they fail to be real, because to be real just is to be tangible. But, would we then be willing to commit to the notion that, say, the steelworkers union is not real because it does not cast a shadow? Or that, say, the idea of money is not real because we cannot smell it? Intuitively, that seems to be a mistake. We want to say that both are yet somehow real. How are we to justify the intuition to *not* reject the reality of unions and money?

The examples of money and unions suggest another layer of analysis. There are at least two senses in which an object that is not tangible can be said to be 'social'. In the first sense, it is a plurality of individual humans gathered and organized for a common purpose. Examples would indeed include a steelworkers union, but also a classroom, a sports team, a philosophical society, a government, or even a nation. In the second sense, a social object is a sort of hybrid individual. It is a composite object, consisting of both a tangible and a social component. Individual bits of currency, and student identification cards would count among such objects, but also such things as chess sets, flags, and planets. Finally, there is yet a third sense that is a bit more subtle than the others. This is the social object that is a "doing" rather than just a "being". The best example of this, is the distinction between a chess *set*, and a chess *match*. More broadly, if we think of a chess match as an *event*, then we might also ask if, say, the French Enlightenment or The Assault on Normandy (aka 'D-Day') are social objects.

Having identified the three kinds of social objects, the question of whether there is any sense in which any of these three kinds of social objects can be count as real in the same sense as a tangible object, or whether there is some other sense of real that might be analogous or equivalent to the reality of a tangible object. I will now examine each of these three notions of social object, and provide some reasons for judging the extent to which they are "really, real".

### Social Objects as Collective Social Beings

It can be argued that social objects of the collective kind are in fact *more real* than their constituent parts, as is seen in Hegel's theory of objective mind (Quinton 1976). Hegel couched his theory in the context of the life of the state in history, but it could also be applied to something a bit less intimidating, like a sports team.  The 1984 Chicago Cubs, picks out a social object we can classify as a team. On Hegel's account, there is (analogously), a spirit of baseball, out of which the team spirit of the 1984 Chicago Cubs becomes a concrete universal (a concept somewhat analogous to the concrete universal of a color, for example). The team's individual members have their reality as that  team, and the team  'only is, as an organized whole' (Quinton 1976, 6).  To pick out individual team members when talking about the team, is to abstract away from the team, rather than to explain it by reducing it to its individuals. This might be thought of as a sort of supervenience view of social institutions, but this is still slightly misleading. The substantial reality is the idea that the group actualizes an already existing spirit, and the individuals in the group are only important insofar as they actualize the spirit of baseball in its concrete form of the 1984 Chicago Cubs.

This view implies an ontology that not only extends beyond the material, but also extends beyond the individual mind (if we take mind to be immaterial). In other words, it posits the ontological reality of a realm of spirit, which has a causal power in the material to the extent that it can give existence or being to certain arrangements of individuals as groups, by giving the group a coherent *meaning*. Hegel called collective beings like states, 'substances', and argued that they are 'actualized' in the material stuff of individuals (Hegel 1807). This is characterisitc of the language of Aristotle, but the concept of the national spirit is more akin to the concept of the Platonic Form, because Hegel's own conception of the spirit of a collective being was one of transcendence, not immanence. To put it another way, Hegel's idea of the collective being is much more akin to the idea of the Catholic Holy Spirit, than it is to the idea of the school spirit of a typical American high school.

Passinsky (2020) makes reference to Orwell's "England Your England", and suggests that Orwell agreed with the antirealist in denying that such things as nations were  "really 'out there' in the world". In fact, Orwell seems to take the Hegelian view in his answer to his own question.[^1]

> "Yes, there is something distinctive and recognizable in English civilization... it has a flavour all its own... it is continuous, it stretches into the future and the past, there is something in it that persists, as in a living creature. What can England of 1940 have in common with England of 1840? But then, what have you in common with the child of five whose photograph your mother keeps on the mantelpiece? Nothing, except that you happen to be *the same person*... above all, it is your civilization, it is *you*. However much you hate it or laugh at it, you will never be happy away from it for any length of time... Good or evil, it is yours, and you belong to it...".

For the purposes of his essay, Orwell drew no significant distinction between the concept of nation, country, and even civilization. He believed in a transcendent British national spirit that animated the whole, and permeated the souls of each individual Briton that belonged to that whole. They depended upon Britain for their British identity (indeed, for their very existence), not the other way around. Very much an analogy of the Hegelian national spirit.

A disciple of Quine might find that this kind of ontological realism comes at far too high a price. Having to commit to an entire transcendent immaterial realm of spirits of reason and identity that give material its meaning and definition would be an extreme extravagance for anyone who preferred Occam to Bonaventure. One alternative to a Hegelian "jungle" ontology (as Quine would put it), would be to turn the concept on its head. Which is to say that such things as teams are *emergent* social objects. Both transcendence and immanence are concepts of objectivity that do not depend *necessarily* on any particular individuals for their reality. But emergence does imply a direct dependence relation. A physical analogy might be the sound that a corrugated tube makes when you swing it round your head. That sound is an emergent property entirely dependent on the particular physical conditions. The tube must be of a particular shape and size, and your motion must be of a particular character, in order produce just that sound.

Likewise, with collective social objects like teams. The team that included Rick Sutcliffe, Ryne Sandberg, and Gary Matthews would not have been the same team, if it hadn't included those athletes. The 1984 Chicago Cubs (and the emergent team spirit), depends for its reality on the presence of the tangible individuals that constitute the team at that particular time. If Rick Sutcliffe, Ryne Sandberg, and Gary Matthews were not a part of the team, it wouldn't *be* the 1984 Chicago Cubs (Theseus notwithstanding). Those men had to come together at that time, to produce that team (and whatever spirit was said to be had of it).

A more general political analogy for this, can be seen in Rousseau's notion of the general will. The entity has no reality, until a particular group of like-minded individuals comes together and unanimously agrees to be governed in a certain way. It is in the precise moment in which they come to unanimous consensus, that the general will is birthed into existence -- and the moment that these individual cease to consent to the contract, the general will ceases to exist. On this view, the general will is as real as the individuals that constitute it, because it emerges as a property of the collective agreement (just like the sound emitting from the spinning corrugated tube is just as real as the tube). However, it depends entirely on the individuals constituting it for its reality, unlike the Hegelian spirit of the state.

But would this satisfy the Quinian? Would Quine accept the concept of a general will into his ontology? Probably not. Quine's eliminativism seems to suggest the necessity to roll back collective notions entirely, until we are left with individuals over which we can quantify variables. In the same way there can be no "average American", there can be no "steelworkers union" or "1984 Chicago Cubs". Terms like "team", and "union", and "nation", are just labels of convenience attached to aggregations of individuals, in order to reduce a cognitive load in the act of communicating, or to reduce the practical or logistical problems inherent in organizing groups of people. Quine's nominalist eliminativism is attractive, because it helps to highlight one way in which subject and object can be demarcated. If we can reduce collectives to individuals, then we can get to something "real". Indeed, contra my own suggestion above, Passinsky (2020) suggests that this is the source of the antirealist intuition about social objects: the degree to which they depend on the subjective is the degree to which they are not real.  To put it in terms of a question, we might ask, where does object stop and subject start? One answer to that is indeed to insist on tangible individuals as the standard of what is real. As we will see, however, it is not so easy to stop even at the level of the objective individual.

### Social Objects as Composite Individual Beings

Earlier, we gave a definition for something called a *tangible*: a unity which has an independent numerical identity, and can be *sensed* or *perceived*. Let's call this common-sense realism. What J.L Austin famously called the reality of "moderate-sized dry goods" (Austin 1979, 8). Interestingly, Quine was also unsatisfied with this definition. He did want to say that real objects were just those objects over which we could bind a variable to a quantity (Quine 1980, 12). However, he broadened the concept far beyond tangibility, when he further argued that quantifiable objects were really only those for which scientific inquiry could provide a satisfying theory (Quine 1980, 44). So, atoms and quarks and elements and forces and fields are given the status of objects because the scientific community has given them to us, in the form of convincing theories. This view has become a dominant feature of contemporary common sense. In a moment, we'll see why this is a problem.

On the Aristotelian view, all real objects are construed to be substances (Aristotle Metaphysics Z.3-Z.11). A substance is the indissoluble composition of *form* and *matter* (a concept called a "hylomorph"). Matter is the material stuff of the composition: dirt, or iron, or wood, or wool, for example. But what is form? In the simplest terms, Aristotelian form is the *definition* of the object. The definition, in turn, is the specification of the object in such a way that picks out the *essence* of the thing. As Aristotle says "*by form I mean the essence of each thing and the primary substance*" (Metaphysics 1032b1), and "*by the substance without matter I mean the essence*" (Metaphysics 1032b14). So, the *essence* of a thing, finally, is that which makes the thing *what* it is. In even simpler terms, it is that which enables us to name a being.

Intrinsic to Aristotelian form, therefore, is the way in which man relates to what he finds in reality. To put it in more modern terms: objects are indeed constituted in part, by our understanding of them. Trees are not trees *until* we discern the *nature* of trees -- and the nature of trees can be found in how they came to be, what they are made of, how they differ from other objects, and what they are for (i.e. the four causes). Until then, they are merely unsubstantial objects, perhaps numerically distinct from other objects, but indefinite and unnamed, like the bronze of a statue, before it is forged into something recognizable.

What is interesting about this theory, is that it extends to social objects in the sense we are considering now. Such things as denominations of currency or borders can be analyzed in terms of their *matter* and their *form*, where the *form* would include the meaning assigned to an object by social agreement. A heavily modified version of this view is taken up by Passinsky (2020). For Passinsky, social objects are *constituted* rather than *composed*. Which is to say, rather than matter and form functioning as co-equal constituents of a hylomorph, material constitution and response-dependence are in a hierarchical "irreflexive and asymmetric dependence relation", where (in Aristotelian terms) the 'form' is dependent upon the 'matter' for its constitution, and the 'matter' is grounded in the 'form'. Passinsky invokes the example of clay and statue in which the clay constitutes the statue and statue grounds the clay. On this view, however, the statue could not be a statue if it were not 'taken to be' a statue, by 'those with the appropriate social standing' to take it as a statue. This raises an interesting problem in other contexts. Let's have a look at different example, to clarify.

There is a consistent experience of the celestial bodies we call planets, up there in the heavens, exhibiting certain properties, and behaving in certain ways. However, there is also continuous dispute over them. Astronomers have been arguing for decades over whether Pluto actually is a planet or not. Before that, they were arguing over whether there was a Pluto at all (whether planet, or not), because observations of the orbits of other planets did not conform to the expectations derived from Newtonian calculations. In a moment, we will see why this is significant, but the focus for now, is a bit different.

The question of whether or not there *is* a Pluto, is a question of its *thatness*. In other words, *that* it exists. The question of whether or not Pluto is *a planet*, is a question of its *whatness*. In otherwords, *what* exists. The former is almost entirely an empirical question. When we look up at the night sky, in the right place, at the right time, do we see something? And can we distinguish it numerically from other somethings that we’ve already seen? There is a minimal amount of social negotiation involved in this, but only to the extent of experiential corroboration. You would be asking your colleague, do you have the same visual experience that I have (or, do your experiments produce the same results)? Assuming you both have reasonably good equipment, are competent with telescopes, and are visually healthy, you’ll come to more-or-less the same answer (as indeed we have, in the case of Pluto). The latter question, however, is a question of identifying *the nature* of the thing seen. Do you see *what* I see? Do you see a *planet*? Today your colleague is likely to say, "no, I see an asteroid" (or a planetoid). The answer you got would depend mainly on the outcome of social negotiations that took place around the time that you asked. In 1966, he would likely have answered, yes, he sees a planet. When the relevant practical authorities cannot come to a consistent consensus on whether or not Pluto is a planet, does it cease to be one? Or, are the various nit-picks of astronomy nerds just so much irrelevant noise to silent Pluto, as it continues its journey around the sun regardless of what they want to call it? It's not clear how to answer that question.

In contrast, returning to the question of tangibile individuals, quite a lot of what counts as a 'real thing' in science is only taken to be so by virtue of consensual agreement amongst the 'relevant authorities'. In other words, those things are objects in spite of the fact that they do not satisfy the definition of tangible, in *any* sense. We might be comfortable admitting things like skin cells and paramecium and even molecules into our collection of tangibles because, although they are not directly sensible, they are sensible with the aid of special tools like microscopes or other equipment (as is the case of many airborne chemicals or nuclear particle radiation), in addition to being outfitted with coherent scientific theories. But there are many more of these things that are insensible even with the aid of special tools, regardless of scientific theories about them.

The common strategy for avoiding this problem, is to say that we sense the effects of those objects, and can infer the presence of the object from the effects. However, it is exactly the opposite process that is taking place in much of fundamental science. We observe some phenomenon, such as the tendency of large masses to move toward each other, or to move in relation to each other in predictable ways. Then, we attempt to exlain what we observe. In attempting to explain the attractive tendency, for example, we posit the entity of gravitation, which would count as the causal source of the phenomenon of attraction. In science, these posited entities are then shopped around in search of agreement. As noted above, this is also the story of Pluto. To be fair, that agreement is normally conditioned on the satisfactory use of a rigorous method that relies on the presuppositions of mathematical order and reliable empirical experiences (of various sorts). However, it is still the case that adherence to a common social ritual of persuasion is what establishes the reality of these objects when they are posited, not their direct tangibility (Kuhn 2012).[^2] In short, many of the objects given to us by science, are social objects, at least for some period of time (until they are either validated or falsified empirically, or reorganized or restructured by new scientific paradigms). In some sense, those objects are more social than money or identity cards. Yet, for the most part, we take those objects to be as real as the plate of eggs in front of me now, or the coat hanging on the hook at my front door.

Thus, while I agree with Passinsky (2020), that "*ordinary material artefacts like tables... can be brought into existence by lone individuals*", it is not clear that objects like the Runnymede Charter Table, or the Table of the Last Supper, or even a chess table, can be brought into existence by a lone individual, because these objects require the stuff of social history for their complete constitution. Without social agreement about what these things are (and not simply whether these things are), they lack their full nature. In Passinsky's terms, they rely on a response-dependence condition, just as much as money and borders do. Likewise, with Pluto.

### Social Objects As Doings

The last kind of social object to be considered is the kind of object that arises out of human behavior, rather than simply an arrangement of human beings, or the meaning assigned to (or identified in) a tangible. These objects are characterized as distinct from the others, in virtue of their *duration*, in addition to their spatio-temporal location. While the 1984 Chicago Cubs have a specific time and place in which it exists as a team, in a roughly static sense, the 1984  Cubs Home Opener game, on the other hand, *occurred over a period of time* (namely, over a span of about two and a half hours on Tuesday, April 3rd). In addition to this, though, the activity was also characterized by something that seems common to collective social objects in general: an agreed-upon common set of rules, and functional roles played by the participants of the activity.

Passinsky (2020) referenced Searle's idea of "constitutive" rules, when outlining her own notion of the constitutive, in contrast to the Searle concept. Searle (1995) uses the rules of the game of chess as an example of what he calls the "constitutive" construction of a social object.[^3]

> It is not the case that there were a lot of people pushing bits of wood around on painted boards, and in order to prevent them from bumping into each other, all the time and creating traffic jams, we had to regulate the activity. Rather, the rules of chess *create* the very possibility of playing chess. The rules are *constitutive* of chess in the sense that playing chess is constituted in part by acting in accord with the rules. If you don't follow at least a large subset of the rules, you are not playing chess... institutional facts exist only within systems of constitutive rules. The system of rules create the possibility of facts of this type.

What Searle is describing, however, is not merely a static object like a chess set, or the constitution of a government. He is describing activities that conform to certain socially accepted sets or systems of rules. For the statement "I mated you in 5" to be a *fact*, it must be the case that you and I were engaged in an activity in which we were both conforming largely to the set of rules that constitute the game of chess, as it is being played. A chess game, in other words, is not just the chess set. It is the chess set, the chess rules, and the activity of moving bits of wood around according to the rules, on a painted board.[^4]

Games are the obvious example of a social object as a "doing" rather than a "being", but the criteria we've set here could be applied in lots of other circumstances. Wars, for example. They involve highly structured social groups, extremely complex sets of rules, sophisticated collections of roles and responsibilities, and have a definite duration in addition to a definite place. For example, The American Civil War, the War of the Roses, and the Franco-Prussian War. Even were these events are apparently chaotic and indeterminate, they still tend to conform to the criteria, as in the Mongol Invasions, or the American Viet Nam war. What's more, there are many, many facts about these events. Facts we take to be as real as weather reports from the times these events occured. Perhaps this is why games and ware are often treated as analogous to one another.

Less clear, might be broader social movements, like the French Enlightenment, or the Fall of Rome, or the rise of the Bolsheviks. These things do not seem to conform to the criteria, apart from the fact that they had a duration (varying in length, depending on  which historian you talk to), and various social roles. Even less clear than that, are things like individual human projects, like the construction of the Empire State building, or the construction of the railroad system in America in the 1860s. There seems to be conformity to some of the criteria: definite duration, certain kinds of context dependent rules, functional roles, and obvious facts. But there still seems to be something intuitively wrong with calling the westward expansion of the railroad, a "social object", even the sense that we would call the 1984 Cubs home opener a "social object".

Perhaps the best way to make sense of this is to appeal to Searle's more controversial notion of "regulative" rules.[^5] An event or a happening is only a "social object", when the rules by which the individuals involved in the event behave, are constitutive of the activity, rather than regulatory of it. So, a chess match, a graduation ceremony, a classroom lecture, and perhaps only certain activities of the state (say, elections, or swearing ceremonies, or congressional hearings), would count as "social objects" of the "doing" kind. While activities like road construction, philosophically motivated social movements, and backyard barbecues would count only as events, and not as objects.

There is unfortunately no more room to explore this idea. Suffice it to say, that when we think about objects like "the game of chess", or "the Tokyo Accords", or even "the Runnymede Charter table", it is not at all clear that we are only talking about an inventory of items.

### Conclusion: Reality And Its Discontents

The upshot of all of this, is that it is beginning to look like it is not possible to escape the fact that the reality of beings (both collective and individual) just is a relation between the intelligibility of existence itself, and the intellect that does the work of intelligent discernment. Since that intellect resides (so far as we are aware) in the skulls of human beings, some degree of subjectivity will always be present in the composition of every object. What is "really 'out there' in the world", is out there in the world, because we can discern it. And, we can discern what is out there, because what is out there, is discernable. The mode of discernment, on this view, is instrumental rather than fundamental, and it is context dependent. For those objects that require rational discernment, we apply a rational method. For those objects that require empirical discernment, we apply an empirical method. For those objects that require a moral discernment, we apply a practical or ethical method. And so on.

Rather than rendering the objects of that discernment *less* real than those that are grasped via mere sense perception, it also seems that certain kinds of discernment actually *contribute* to the reality of the object. So, as Aristotle understood, some objects are *more real* by virtue of the fact that we have had to explain them, than those objects that we have not (or cannot). This includes at least some of the so-called social objects.


[^1]: Orwell, George, England Your England, 1941, Pp. 2-3

[^2]: See Kuhn Chapters 3, 4, and 5, in which he argues that scientific theories are the outcomes of a shared set of paradigmatic examples, combined with a commonly understood set of rules for their use, that are then propagated across scientific disciplines by a process of indoctrination - meant in a non-perjorative sense - and various kinds of social enforcement.

[^3]: Passinsky is contrasting Searles notion of *counting as*, with her own notion of *constitutes*, but I want to use Searle for a different reason. Namely, that implied in the example of the chess game is the fact that social reality is not merely collections of items, but a forum for action, and that some actions, when engaged in socially, can count as objects in their own right.

[^4]: To be clear, I am not suggesting that Searle would have called a chess match a social object. He does not seem to think in these terms at all. I am simply suggesting that his example independently evokes the notion of another class of social object he may not have thought of -- and perhaps would not even agree with.

[^5]: See Passinsky for references discussing the controversy. 
