---
title: "Nozick, Rawls, and the Problem of Patterned Principles of Justice"
date: 2022-04-18T12:33:22+01:00
tags: ["rawls", "nozick", "hayek", "patterned distributions", "free market", "liberty", "equality"]
topics: ["philosophy", "politics"]
image: img/nozick-and-rawls.jpg
description: The conflict between immanent and transcendent order continues...
draft: false
---

Responding to John Rawls egalitarianism, Robert Nozick responds that "*....in a socialist society... no end-state principle or distributional patterned principle of justice can be continuously realized without continuous interference with peoples' lives. Any favoured pattern would be transformed into one unflavored by the principle, by people choosing to act in various ways...*" (Nozick 1974, 163) This essay will argue that Nozick's objection is successful against Rawls, only to the extent that it is understood in the context of Rawls' understanding of his own theory. If Nozick is correct, then Rawls insistence on the priority of liberty is flawed because his Difference Principle is incommensurable with his Liberty Principle. Further, this paper will then argue that the objection is only a necessary step in a fully sufficient set of reasons for rejecting Rawls' complete Theory of Justice. Finally, it will end by highlighting a puzzle at the heart of the dispute between Nozick and Rawls that has yet to be solved.

## Nozick's Real Objection

It is commonplace to frame Nozick's objection to Rawls as a general objection from an axiomatic commitment to individual liberty. There is some ground for this. Nozick defends his own theory of justice from a Lockean position of self-ownership (Nozick 1974, 171):

> *The central core of the notion of a property right in X, relative to which other parts of the notion are to be explained, is the right to determine what shall be done with X; the right to choose which of the constrained set of options concerning X shall be realized or attempted... in our theory, by the Lockean rights people possess... [The] notion of property helps us to understand why earlier theorists spoke of people as having property in themselves and their labor. They viewed each person as having a right tot decide what would become of himself...*

It is out of this basic commitment to self-ownership that Nozick's notion of justice in acquisition arises, and it is true that Nozick relies on the reader's own intuitions about Lockean property rights when defending this notion. So, for someone already convinced of self-ownership, this would be a powerful argument. But what purchase would such an objection have with someone who did not come pre-equipped with a commitment to Lockean self-ownership (such as a Burkean Conservative or a Marxist)? Nozick would complain that Rawls' theory would require regular egregious violations of individual liberty, and the Marxist would respond, "so what"?

As it turns out, Rawls claims to be a defender of "liberty of person" (Rawls 1999, 53) in A Theory of Justice, and he defines liberty as the first of two essential principles of justice, the other being difference. Further, he gives the liberty principle explicit priority over the difference principle. Rawls defines his Liberty Principle as "*each person [having] an equal right to the most extensive scheme of equal basic liberties compatible with a similar scheme of liberties for others.*" (Rawls 1999) Of the Difference Principle, Rawls says that "social and economic inequalities are to be arranged so that they are both (a) reasonably expected to be to everyone's advantage, and (b) attached to positions and offices open to all." (Rawls 1999) Thus arises the obvious question: how is it that the Difference Principle could be successfully achieved, when at every turn, it would be confronted by the Liberty Principle?

So, if we wish to take Nozick seriously, then we must first accept that he was not making a general objection that simply assumed a commitment to Lockean property rights or self-ownership. Rather, Nozick's objection was to some perceived error in the way Rawls had conceived of these two principles interacting with each other. Namely, that an earnest application of the Difference Principle would result in the continuous violation of the Liberty Principle, thus rendering Rawls' theory untenable. But is Nozick right about this?

## Rawls' Egalitarianism: The Opposition of Liberty and Property

To understand whether this is the case, we need to better understand what Rawls means by "having an equal right to... basic liberties...", and how enforcing an end-state patterned distribution of mitigated inequalities under the difference principle would systematically disturb that equal right. To begin this examination, we can ask why Rawls keeps attaching the qualifier "basic" to the list of liberties associated with the liberty principle? What does he mean by "basic"? Rawls offers an explanation by way of description (Rawls 1999, 54):

> *...basic liberties are given by a list... political liberty (the right to vote and to hold public office) and freedom of speech and assembly; liberty of conscience and freedom of thought; freedom of the person, which includes freedom from psychological oppression and physical assault and dismemberment (integrity of the person); the right to hold personal property and freedom from arbitrary arrest and seizure as defined by the concept of the rule of law... [the liberty principle] is prior to [the difference principle]... infringements on the basic equal liberties protected by [the liberty principle] cannot be justified , or compensated for, by greater social and economic advantages. These liberties have a central range of application within which they can be limited and compromised only when they conflict with other basic liberties...*

So "basic" liberties are, more-or-less, the right to things we would find enumerated in the American constitution's famous Bill of Rights (the first 10 amendments), and they are "basic" because they are grounded in something other than a utilitarian goal (though Rawls is not explicit about this). However, he says they are not absolute (because they can be limited when clashing with each other). Still, they are to be shielded against complaints anyone might make on consequential grounds from the point of view of the Difference Principle. In short, no matter how much better it might be for the worst off, infringement of my right to property is sacrosanct.

However, this list is not as expansive as it might first seem. Though he says here that "the right to hold personal property" and "freedom of person" qualify as "basic", he goes on to say that "*the right to own certain kinds of property (e.g., the means of production) and freedom of contract as understood by the doctrine of laissez-faire" (Rawls 1999, 54) are not basic, and as such are not protected by the priority of the liberty principle.Why does Rawls make this distinction between "personal" property and property that constitutes the "means of production"? And why does he separate the "freedom of person" from the freedom to contract?

Rawls is making an appeal to Karl Marx here, who argued that "land, labor, and capital" (Oxford Reference 2021) were a form of property in a Capitalist system needed to produce goods and services. He further argued that the class division between the Capitalist and the proletariat prevented the proletariat from supplying themselves independently with the goods they required to lead lives consistent with their nature as productive beings. (Livingstone and Benton 1992, 322-330) Capitalist hoarding of the means of production is a denial of the basic liberty of the proletariat to fend for themselves. Any form of property that could result in a denial of basic liberty could not therefore be counted among the basic liberties.

Rawls, in short, is importing the entire ideology of Socialism into his Theory of Justice right at the outset, with barely more than a parenthetical mention. Why is this a problem? For two reasons. First, as Nozick points out, it is not so clear what the difference really is between personal property and property meant for production. While defending his famous Wilt Chamberlain thought experiment, he offers this tantalising suggestion (Nozick 1974, 162-163):

> *...I melt down some of my personal possession [after arriving in the starting state of the ideal distribution pattern] and build a machine out of the material. I offer you, and others, a philosophy lecture once a week in exchange for your cranking the handle on my new machine, whose products I exchange for yet other things, and so on (the raw materials used by the machine are given to me by others who possess them [under the starting ideal patterned distribution] in exchange for hearing lectures)...*

Suppose the materials he initially melts down are the cutlery he was allotted at the beginning of the patterned distribution, and the resulting machine was cast out of the dirt in his back yard. Suppose the products he creates with it, are home-made jewelry or key rings or something else more useful (like new cutlery)? Was the cutlery he started with originally, a means of production? Let us make it even simpler. Suppose he does not make a machine at all but uses the cutlery as-is to bake pies and exchanges the pies for philosophy lectures. Is the cutlery then a "means of production"? Marx might object to the question, on the grounds that Nozick was simply acting on his own nature as a productive species-being and helping himself to that impulse to fend for himself in nature. In other words, Nozick would not count as one of the Capitalists because he was not hoarding the means of production, but rather was merely using his own personal possessions to satisfy his own procreative needs.

The point here is not to relitigate Marxism, but to highlight Rawls' use of the property distinction in his enumeration of the relationship between basic liberties and inequalities. One implication of the importation of Marx, is that there is some unspecified point at which individual productive activity (which will inevitably lead to exchanges of goods - "transfers of wealth", as Marx might put it) is transformed from a life-sustaining pursuit of one's nature, into an adventure in Capitalist exploitation. Rawls wants economic circumstances to be the medium by which that transformation is measured, and for a certain degree of economic inequality to be the moment of detection. At some point of divergence from the ideal pattern, Nozick's cutlery (melted down or otherwise), stops being his personal property (to which he is entitled by right, protected by the priorty of the Liberty Principle), and starts being the property of production (to which he is not entitled by right, and over which the state has the authority to redistribute).

Nozick seems to think that individuals would be entitled to exchange goods and services amongst themselves, under the "favored distributional pattern" of a system like Rawls'. But how could they be, if the free use of personal property would inevitably lead to an unjust divergence from the favored distributional pattern? This is why Rawls needs the distinction between personal property and the means of production. By putting everything that can cause a divergence into the "means of production" box, he hopes to escape the problem of untenable relations between his two principles. 

Thus, "basic" liberties only include property ownership until the ownership in question has produced a distribution pattern that (as Rawls would put it) "is not to the benefit of all" (Rawls 1999, 54) In short: property ownership is protected from the Difference Principle by the priority of the Liberty Principle until the moment when state decides that the Difference Principle is more important. The point is put more clearly by John Meadowcroft: (Bader and Meadowcroft 2011, 177)

> "Once holdings/entitlements/property rights are understood to be less than absolute, in Rawls' case as a result of the hypothetical unanimous agreement of all parties, then it is not clear on what basis the taxation and redistribution of part of Chamberlain's additional income in accordance with such an agreement could be considered unjust."

Thus, Nozick is not simply saying that the difference principle would necessitate occasional unjust interventions to nudge the socialist society back toward the ideal pattern of distribution. He is saying that no notion of property ownership could be sustained in a socialist society, because that would lead continuously to "capitalist acts between consenting adults", and that would always lead to a divergence from the ideal pattern. In other words, the distinction between personal property and the means of production is essentially meaningless in the context of a commitment to patterned distributions, and consequently, Rawls' Liberty Principle is at best a mere sentiment, at worst, a self-deception.

## Liberty vs Order: A Metaphysical Dichotomy

Nozick put it succinctly: liberty upsets patterns. Another way to put this, is that liberty and patterns are incompatible goals. However, it is not enough just to show that there is an irreconcilable tension between the Liberty Principle and the Difference Principle. To have sufficient reason to reject Rawls' theory, we must also show why this tension is irreconcilable, and why liberty is preferable in the end.

Nozick is not making a principled objection to patterns as such, but only to patterns that are imposed as part of an idea of justice. However, in a state of liberty, whatever patterns that might arise from the individual interactions of free people making free choices according to some general set of common rules, is not going to be something that can be rationally predetermined. This is also a point made much more forcefully by Friedrich Hayek (Hayek 1960, 76-77)

> *From the fact that people are very different it follows that, if we treat them equally, the result must be inequality in their actual position, and that the only way to place them in an equal position would be to treat them differently. Equality before the law and material equality are therefore not only different but are in conflict with each other; and we can achieve either the one or the other, but not both at the same time... the desire of making people more alike in their condition cannot be accepted in a free society as a justification for... coercion... a demand for equality is the professed motive of most of those who desire to impose upon society a preconceived pattern of distribution...*

At the heart of Nozick's critique of Rawls, is a dispute about the fundamental nature of justice itself. Rawls takes the Platonic view, in which justice is a harmonious arrangement of parts of a whole. Nozick takes the Aristotelian view, in which justice is a measure of the proportional value exchanged in human interactions. To put it more simply, it is a dispute over whether justice is, at its core, structural or procedural. Nozick takes the procedural understanding, and that puts him squarely in the libertarian camp complete with its own set of basic assumptions. Again, I will let Hayek explain the position (Hayek 1960, 87)

> *Justice, like liberty and coercion, is a concept which, for the sake of clarity, ought to be confined to the deliberate treatement of men by other men... Insofar as we want the efforts of individuals to be guided by their own views about prospects and chances, the results of the individual's efforts are necessarily unpredictable, and the question as to whether the resulting distribution of incomes is just has no meaning.*

The structural understanding, too, will come with a set of assumptions of the kind that Rawls includes in A Theory of Justice. Among those assumptions is egalitarianism, which is an inevitability inherent in the concept of the original position, according to Nozick. He helps to make this problem starkly clear in a subsequent thought experiment in the same chapter as the Wilt Chamberlain thought experiment (Nozick 1974, 199-200)

> *Suppose there were a group of students who have studied during a year, taken examinations, and received grades between 0 and 100 which they have not yet learned of. they are now gathered together, having no idea of the grade any one of them has received, and they are asked to allocate grades among themselves so that the grades total to a given sum... let us suppose they are to decide jointly upon a particular distribution of grades; they are to give a particular grade to each identifiable one of them present at the meeting... Next suppose that they are unanimously to agree not to a particular distribution of grades, but rather to general principles to govern the distribution of grades... What principle would be selected? The equality principle, which gives each person the same grade, would have a prominent chance... and if it turned out that the total was variable depending upon how they divided it, depending on which of them got what grade, and a higher grade was desirable... then the principle of distributing grades so as to maximize the lowest grades might seem a plausible one. Would these people agree to the non-end-state historical principle of distribution: give people grades according to how their examinations were evaluated by a qualified and impartial observer?*

Nozick says no, they would not. If they were in the original position, they would have no knowledge of the historical process that led to the grades in question, and as such, there is no way in which a particular assignment could appear just (indeed, receiving the exact opposite of ones actual grade would appear as unjust as ones actual grade, because there would be no way to know the difference). So, justice would come down to a purely probabilistic calculation, grounded entirely in nothing but abstract self-interest about where in the global arrangement one might end up. In other words, no other conception of justice is possible in the original position but an end-state conception. As Nozick put is: "The nature of the decision problem facing persons deciding upon principles in an original position behind a veil of ignorance limits them to end-state principles of distribution." Thus, Rawls' Theory of Justice is already assuming what it seeks to prove.

Nozick's own answer to this is to insist upon a "historical" conception of justice, split into two core principles: justice in acquisition (or holding) and justice in transfer. These terms obfuscate the Aristotelian nature of his theory. What he is describing with these two principles is the question of what is owed to the individual in any given exchange of value. In the case of the students and their grades, the point is obvious: the grade that is owed to the individual is the grade that he earned by virtue of his own study and effort. Echoing Hayek, then, Nozick argues that notions of redistribution based on a veil of ignorance are obviously nonsensical in the context of the actual circumstances (which could not be known in the original position).

Nozick calls the student's grade an "entitlement", but the more archaic term desert1 seems more appropriate. Justice consists in giving and receiving what is deserved, and that requires particular knowledge about what led to the exchange, and particular knowledge about the individuals involved in the exchange. Aristotle would have expressed this in terms of mathematical proportions, but we need not get bogged down in calculations of ratio and proportion to understand the point here. The patterns of justice reside first in individual acts of giving and receiving, not in any ideal pattern that emanates from those particular exchanges.

In a political system in which an end-state pattern is the idea the of justice, every exchange between individuals would have to be prescribed by the authority governing the pattern. Otherwise, individually motivated exchanges would result in varying degrees of injustice, according to the degree to which the exchange produced a divergence from the ideal end-state pattern. Thus, not only would continuous interference be necessary to "right the ship", it would be the only form of just action in such a society.

## Conclusion

Thus, this essay has demonstrated that Rawls theory appears untenable because of an irreconcilable opposition between liberty and patterned distributions. However, it will be noticed at this point that a problem raised near the beginning of this essay is not resolved. To complete our case against Rawls, it has been necessary to re-import the very presupposition of liberty we fended off initially. However, this is no rescue for Rawls' theory. Because, as was explained in the third argument, Rawls is labouring under a whole set of his own unjustified presuppositions. Fundamentally, the dispute comes down to the opposition between the structural and procedural views of justice - "equality of condition" versus "equality under the law" is the way Hayek expressed it. Harmonious order, versus proportionate desert, as it would have been understood by Plato and Aristotle.

It is not at all clear that this dispute has an answer. On the one hand, it is encouraging that thinkers as recent as Nozick and Rawls can restate with some degree of sophistication this eons old conflict in human thought. It means we are still grappling seriously with the problem, and that can be a source of hope. On the other hand, the fact that this puzzle still has no clear answer after generations of mankind's most productive minds devoting themselves to it, suggests that there may be no clear answer -- at least, here on earth.

## References

Rawls, John. 1999. A Theory of Justice. Revised Ed. United States: Harvard University Press

Nozick, Robert. 1974. Anarchy, State, and Utopia. Malden, MA, USA: Blackwell Publishing.

Hayek, Friedrich. 1960. The Constitution of Liberty. Abingdon, UK: Routledge Classics.

Livingstone, Rodney, and Benton, Gregor. 1992. Karl Marx: Early Writings. London, UK: Penguin Classics

Meadowcroft, John. 2011. "Nozick's critique of Rawls: distribution, entitlement, and the assumptive world of A Theory of Justice". In The Cambridge Companion to Nozick's Anarchy, State, and Utopia, Cambridge, 2011, 168-196
