---
title: "The Digital Panopticon"
date: 2022-11-25T11:03:54Z
tags: ["home automation", "internet of things", "big tech", "internet 2.0"]
topics: ["politics", "sociology", "psychology", "ethics"]
image: img/panopticon-scaled.jpg
description: Another Enlightenment promise made false by sin
draft: false
---
I had a Nest thermostat (before it was gobbled up by Google) many years ago in a home in New Hampshire. It ran a furnace that burned supposedly eco-friendly pellets. To be honest, my only interest in the furnace was that it offered an economical alternative to the established expensive centralized gas utility.

The thermostat was sufficient. I never used the phone app designed for it because the house was too small, and I saw no benefit in adjusting the temperature of my house while at the grocery store. I did have to reboot it relatively frequently. Every time I did, the question of why this needed to be a linux node kept getting bigger and bigger in my mind. By the time I got rid of the house (only a couple of years later) I didn't want to have anything to do with "home automation". Let me take a step back to explain why.

## Ancient History

When tech really started exploding as an accessible consumer/retail product option in the late 1980s, there was a great deal of optimism and idealism that came along with it. It was all about how much control you'd have over *your own* life, and how many more options it would make available *to you*. New ways to play, new ways to study, new ways to work, new ways to make friends, keep in touch with family, entertain each other, and record memories.

This ethos of putting power into the hands of the individual was what gave birth to the Open Source and Free Software movements. You want to let us have control over our own lives? Great. Then give us the power to build and shape them as we please. That means empowering people to *build their own* experiences on the computer, and then later, on the internet. Give us programming languages, compilers, hardware schematics, interoperability of peripherals, uniformity of protocols, etc. We'll do the rest ourselves, thank you.

This worked for a long time, while everything came at a price. You paid outright for your computer, for your peripherals, and your accessories. You were charged monthly for your phone line. You paid a subscription fee for your Compuserv, AOL, or ISP connection. Computer clubs, swap meets, flea markets, and technical magazines were everywhere. It wasn't hard at all to find a local group to connect with, and share projects, ideas, and information. When the internet came along, it got even easier. Instead of swapping boxloads of disks, now you could just ftp whatever you needed. But all of that has since changed.

## The Dot-Com Bust

At first, it was just annoying, but it seemed necessary. The emphasis on empowerment came with loads of strings-attached rules: let us keep track of what you're doing, and the sorts of things you're interested in, using cookies, email forms, and login accounts. If you let us, then it will be a lot cheaper. But, what you give us in exchange is the ability to sell advertising to you on our websites and quantify our userbase to advertisers.

This appears to have been a deal made with the devil. Because not long after, online sharing suddenly became "thievery" and "piracy" and there were massive lawsuits and even federal criminal charges tossed around. And the surveillance regime has gradually expanded into every possible nook and cranny of tech. It's now even in places like your BIOS, and the TOR network. It's inescapable. And it's not just for monetization. It's an ever-widening constantly flowing river of sustenance for both corporate and government bureaucrats to dip into whenever they need an excuse for their existence.

And finally, now, we have the arrival of such things as "social credit scores". Where the promise of the computer, and its nearly ubiquitous companion the internet, is turned completely on its head. Where you were once to leverage these innovations to empower yourself and gain more control over your own life, you now have a looming beast that is a constant threat ready to pounce when you do or say anything that looks like independent behaviour -- and it is frequently exercising new powers of its own over you and your family, without so much as a whimper from the defenders of open computing and online freedom.

What was supposed to be the fulfillment of the Enlightenment dream of the Panpaedia, has rather become the realisation of Betham's Panopticon. Banks want to use the internet to [regulate your spending habits](https://mstr.cd/3FS1OFl) according to socio-political goals. Energy companies want to use the internet to [regulate your household utilities](https://bit.ly/3BWx44Z) according to socio-political goals. Insurance companies and government health services want to use the internet to [regulate your food purchases and eating habits](https://bit.ly/3WnsNQe) according to socio-political goals. And of course, we're all now extremely familiar with the way that social media services have been used to [herd and manipulate public opinion](https://www.theguardian.com/technology/2011/mar/17/us-spy-operation-social-networks), and to [punish people who fall outside the herd](https://www.nationalreview.com/news/fbi-was-in-constant-contact-with-twitter-trust-and-safety-team-documents-show/). There are dozens more examples. But you get the idea.

## All Your Living Are Belong To Us

The "home automation" hobby was stillborn into this environment only just about 15 years ago. Little companies like Nest, FitBit, and Pandora were quickly gobbled up by corporate giants, and burgeoning markets like Smart TVs were quickly dominated by amoral brand names like Samsung and their software stack colonised immediately by Google, Microsoft, and Sony.

What might have been a fun and challenging way for someone with the "tech bug" to "electrify" his home, has in fact materialized as a creeping, multi-tentacled octopus, whose tendrils are busy tracking your every movement, tallying your every consumption, recording your every spoken word, even predicting things like the pregnancy of your daughter, and then reporting it all back to corporate masters who need you to be compliant and predictable, both for the sake of quarterly returns, *and* in service to the "Environmental, Social, and Governance" goals they must meet in order to keep the investment capital pipeline flowing.

In short, what began as the single most promising opportunity to empower the individual, has indeed become the single most threatening danger to virtually all of his freedoms, including those he had previous to its invention.

This is the most disheartening realisation of my entire life. When I was in my 20s, I was completely on board with all of this. I ached for the day that I could "Star Trek" my entire house. I wanted a computer in every room. I wanted network sockets on every wall. I wanted a GB fiber pipe straight to my door. I wanted voice activated appliances. I wanted vital sign trackers. I wanted instant music in the walls. All of it.

Now, however, I keep all my tech in one room that has a locked door. When I go out of doors, I carry a laptop and/or "smart" phone only when absolutely necessary. I've never owned anything like an Amazon Alexa, and I don't use Google on my phone. It's profoundly sad that it has come to this. When I was young, the benefits of all of this stuff seemed like a no-brainer. Now, the dangers of it all are ever-present. And the more I contemplate on the question, the more I'm convinced that the tech itself is not the problem.

It's us.

The situation we're in now was as inevitable in 1914, and 1944, and 1984, as it was in 2014. Why? Because it doesn't have anything to do with specific architectures, or protocols, or commercial arrangements, or even political circumstances. It has to do with human nature. We're never satisfied with satisfying ourselves. We can't help but enlist our neighbour in our endeavours, either by persuasion or coercion. Thus, the more power we give ourselves over our own lives, the more tempted we are to exercise it over others.

It is the curse of the original sin (whether you take that literally or allegorically is beside the point). And it is why self-satisfaction will never work as an ultimate goal; why our ultimate aim must, inevitably, point to something beyond satisfying the self. And as long as we refuse to do that, then the more mastery we gain over the material world, the more likely it is that we will destroy ourselves.

Thus, my turn away from technologies of this sort is not mere luddism, a "back to nature" fantasy, "simple-life-ism", or even a distrust of google (which I do have). It is submission to a basic humility. As the stoics liked to (wisely) point out often: your life was never yours to control in the first place. You are a tenant, a traveller, a visitor. The best you can hope for, is that you return what you've used in as good a condition as when it was lent to you by its actual owner. And, to do that, I have to avoid those things that would tempt me to imbibe in the fantasy of control. Because it is that fantasy that renders me a slave to those who would instead control me.
